pytilities.geometry.discretevector — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »

# pytilities.geometry.discretevector

class `pytilities.geometry.discretevector.` `DiscreteVector`(*args, **kwargs)

  2D Point/Vector with coordinates in a discrete space (integer).

  Note on Vector, DiscreteVector operations: Vector op DiscreteVector returns Vector. DiscreteVector op DiscreteVector returns DiscreteVector.

  Note that a DiscreteVector does not support truediv (/), it does support floordiv(//) however.

  `__delattr__`(*args, **kwargs)
  `__getattribute__`(*args, **kwargs)
  `__init__`(*args, **kwargs)
  `__setattr__`(*args, **kwargs)

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »